aboutsummaryrefslogtreecommitdiff
path: root/gcc/config/m68k
diff options
context:
space:
mode:
authorAndreas Schwab <schwab@issan.informatik.uni-dortmund.de>1998-03-30 01:14:16 +0000
committerAndreas Schwab <schwab@gcc.gnu.org>1998-03-30 01:14:16 +0000
commite18db50d1f83eb98b5d72550c67ace78e41ee7b0 (patch)
tree606bbb808b40cc791b3c39230cb48626b67ece63 /gcc/config/m68k
parentc0d45032293ac50b0cf63cad2cc0669010f1dbeb (diff)
downloadgcc-e18db50d1f83eb98b5d72550c67ace78e41ee7b0.zip
gcc-e18db50d1f83eb98b5d72550c67ace78e41ee7b0.tar.gz
gcc-e18db50d1f83eb98b5d72550c67ace78e41ee7b0.tar.bz2
m68k.c (standard_68881_constant_p): Don't use fmovecr on the 68060.
* config/m68k/m68k.c (standard_68881_constant_p): Don't use fmovecr on the 68060. From-SVN: r18907
Diffstat (limited to 'gcc/config/m68k')
-rw-r--r--gcc/config/m68k/m68k.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/gcc/config/m68k/m68k.c b/gcc/config/m68k/m68k.c
index c6fb663..567ccdf 100644
--- a/gcc/config/m68k/m68k.c
+++ b/gcc/config/m68k/m68k.c
@@ -1,5 +1,5 @@
/* Subroutines for insn-output.c for Motorola 68000 family.
- Copyright (C) 1987, 93, 94, 95, 96, 1997 Free Software Foundation, Inc.
+ Copyright (C) 1987, 93-97, 1998 Free Software Foundation, Inc.
This file is part of GNU CC.
@@ -2414,8 +2414,9 @@ standard_68881_constant_p (x)
return 0;
#endif
- /* fmovecr must be emulated on the 68040, so it shouldn't be used at all. */
- if (TARGET_68040)
+ /* fmovecr must be emulated on the 68040 and 68060, so it shouldn't be
+ used at all. */
+ if (TARGET_68040 || TARGET_68060)
return 0;
#ifndef REAL_ARITHMETIC